==> minexpert2_7.4.1.orig.tar.gz: minexpert2-7.4.1/src/gui/BaseColorMapPlotWnd.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2019 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */

#pragma once


/////////////////////// StdLib includes


/////////////////////// Qt includes
#include <QMainWindow>


/////////////////////// pappsomspp includes
#include <pappsomspp/widget/plotwidget/colormapplotconfig.h>

/////////////////////// Local includes
#include "ui_BasePlotWnd.h"
#include "BasePlotWnd.hpp"
#include "BaseColorMapPlotCompositeWidget.hpp"


namespace msxps
{
namespace minexpert
{


class MsRunDataSet;
class ProgramWindow;
class DataPlotGraphNode;

class BaseColorMapPlotWnd : public BasePlotWnd
{
  Q_OBJECT

  public:
  // Construction/destruction
  BaseColorMapPlotWnd(QWidget *parent,
                      const QString &title,
                      const QString &settingsTitle,
                      const QString &description = QString());
  virtual ~BaseColorMapPlotWnd();

  // This one cannot be implemented here because each derived class will need to
  // instantiate the proper subclass of BaseColorMapCompositeWidget.
  virtual QCPColorMap *
  addColorMapPlot(std::shared_ptr<std::map<double, pappso::MapTrace>>
                    &double_map_trace_map_sp,
                  const pappso::ColorMapPlotConfig &color_map_plot_config,
                  MsRunDataSetCstSPtr ms_run_data_set_csp,
                  const ProcessingFlow &processing_flow,
                  const QColor &color,
                  QCPAbstractPlottable *parent_plottable_p) = 0;

  QCPColorMap *finalNewColorMapPlotConfiguration(
    BaseColorMapPlotCompositeWidget *composite_widget_p,
    std::shared_ptr<std::map<double, pappso::MapTrace>>
      &double_map_trace_map_sp,
    const pappso::ColorMapPlotConfig &color_map_config,
    MsRunDataSetCstSPtr ms_run_data_set_csp,
    const ProcessingFlow &processing_flow,
    const QColor &color,
    QCPAbstractPlottable *parent_plottable_p);

  virtual void integrateToMz(QCPAbstractPlottable *plottable_p,
                             const ProcessingFlow &processing_flow);

  virtual void integrateToDt(QCPAbstractPlottable *plottable_p,
                             const ProcessingFlow &processing_flow);

  virtual void integrateToDtMz(QCPAbstractPlottable *plottable_p,
                               const ProcessingFlow &processing_flow);

  virtual void integrateToRt(QCPAbstractPlottable *plottable_p,
                             const ProcessingFlow &processing_flow);

  virtual void integrateToRtMz(QCPAbstractPlottable *plottable_p,
                               const ProcessingFlow &processing_flow);

  virtual void integrateToRtDt(QCPAbstractPlottable *plottable_p,
                               const ProcessingFlow &processing_flow);

  public slots:

  signals:

  protected:
	void setupToolBar();
  QAction *mp_transposeAxesAct = nullptr;
};


} // namespace minexpert

} // namespace msxps

==> minexpert2_8.2.0.orig.tar.gz: minexpert2-8.2.0/src/gui/BaseColorMapPlotWnd.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2019 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */

#pragma once


/////////////////////// StdLib includes


/////////////////////// Qt includes
#include <QMainWindow>


/////////////////////// pappsomspp includes
#include <pappsomspp/widget/plotwidget/colormapplotconfig.h>

/////////////////////// Local includes
#include "ui_BasePlotWnd.h"
#include "BasePlotWnd.hpp"
#include "BaseColorMapPlotCompositeWidget.hpp"


namespace msxps
{
namespace minexpert
{


class MsRunDataSet;
class ProgramWindow;
class DataPlotGraphNode;

class BaseColorMapPlotWnd : public BasePlotWnd
{
  Q_OBJECT

  public:
  // Construction/destruction
  BaseColorMapPlotWnd(QWidget *parent,
                      const QString &title,
                      const QString &settingsTitle,
                      const QString &description = QString());
  virtual ~BaseColorMapPlotWnd();

  // This one cannot be implemented here because each derived class will need to
  // instantiate the proper subclass of BaseColorMapCompositeWidget.
  virtual QCPColorMap *
  addColorMapPlot(std::shared_ptr<std::map<double, pappso::MapTrace>>
                    &double_map_trace_map_sp,
                  const pappso::ColorMapPlotConfig &color_map_plot_config,
                  MsRunDataSetCstSPtr ms_run_data_set_csp,
                  const ProcessingFlow &processing_flow,
                  const QColor &color,
                  QCPAbstractPlottable *parent_plottable_p) = 0;

  QCPColorMap *finalNewColorMapPlotConfiguration(
    BaseColorMapPlotCompositeWidget *composite_widget_p,
    std::shared_ptr<std::map<double, pappso::MapTrace>>
      &double_map_trace_map_sp,
    const pappso::ColorMapPlotConfig &color_map_config,
    MsRunDataSetCstSPtr ms_run_data_set_csp,
    const ProcessingFlow &processing_flow,
    const QColor &color,
    QCPAbstractPlottable *parent_plottable_p);

  virtual void integrateToMz(QCPAbstractPlottable *plottable_p,
                             const ProcessingFlow &processing_flow);

  virtual void integrateToDt(QCPAbstractPlottable *plottable_p,
                             const ProcessingFlow &processing_flow);

  virtual void integrateToDtMz(QCPAbstractPlottable *plottable_p,
                               const ProcessingFlow &processing_flow);

  virtual void integrateToRt(QCPAbstractPlottable *plottable_p,
                             const ProcessingFlow &processing_flow);

  virtual void integrateToMzRt(QCPAbstractPlottable *plottable_p,
                               const ProcessingFlow &processing_flow);

  virtual void integrateToDtRt(QCPAbstractPlottable *plottable_p,
                               const ProcessingFlow &processing_flow);

  public slots:

  signals:

  protected:
	void setupToolBar();
  QAction *mp_transposeAxesAct = nullptr;
};


} // namespace minexpert

} // namespace msxps
